import xHttp from '@/apis/Xhttp'
import { FORM_DESIGN_URL } from '@/apis/url'
import { saveAs } from 'file-saver'
import { formDesignResult, formDesignSearch, formDesignSearchResult } from './types'
import { message } from 'ant-design-vue'
import { roleData } from '@/apis/role/types'
export default {
  /**
   * 表单定义文件详情
   * @param {*} formId 表单id
   * @returns
   */
  async queryFormDesign(formId: string) {
    const res = await xHttp.get<formDesignResult>(FORM_DESIGN_URL.QUERY(formId))
    return res.table_content
  },
  /**
   * 表单定义文件查询
   * @param {*} params 查询参数
   * @returns
   */
  async searchFormDesign(params?: formDesignSearch) {
    return await xHttp.get<formDesignSearchResult, formDesignSearch>(FORM_DESIGN_URL.SEARCH, params)
  },
  /**
   * 表单定义文件添加
   * @param {*} json json数据
   * @returns
   */
  async addFormDesign(json: FORM.DEF) {
    return await xHttp.post(FORM_DESIGN_URL.DEPLOY, json)
  },
  /**
   * 表单定义文件更新
   * @param {*} formId 表单id
   * @param {*} json json数据
   * @returns
   */
  async updateFormDesign(formId: string, json: FORM.DEF) {
    return await xHttp.put(FORM_DESIGN_URL.UPDATE(formId), json)
  },
  /**
   * 删除表单定义文件
   * @param {*} formId 表单id
   * @returns
   */
  async deleteFormDesign(formId: string) {
    return await xHttp.delete(FORM_DESIGN_URL.DELETE(formId))
  },
  // 表单定义导入
  async formDesignImport(file) {
    const formData = new FormData()
    formData.append('file', file)
    return await xHttp.post(FORM_DESIGN_URL.FORM_IMPORT, formData)
  },
  /**
   * 表单定义下载
   * @param {string} data  下载的表单定义列表  表单name[]
   */
  async formDesignExport(data: string[], name = '表单定义数据') {
    try {
      message.info(`开始下载${name}...`)
      const blob = await xHttp.postDownload(FORM_DESIGN_URL.FORM_EXPORT, data)
      saveAs(blob, `${name}.json`)
    } catch (error) {
      message.error(error.msg)
    }
  },
  /**
   * 表单授权角色列表
   * @param {*} formName 表名
   * @returns
   */
  async resourceList(formName: string) {
    return await xHttp.get<roleData[]>(FORM_DESIGN_URL.RESOURCE_LIST(formName))
  },
  /**
   * 表单授权角色
   * @param {*} formName 表名
   * @param {*} ids 操作角色id
   * @returns
   */
  async resourceBind(formName: string, ids: string[]) {
    return await xHttp.post(FORM_DESIGN_URL.RESOURCE_BIND(formName), ids)
  },
  /**
   * 表单取消授权角色
   * @param {*} formName 表名
   * @param {*} ids 操作角色id
   * @returns
   */
  async resourceUnbind(formName: string, ids: string[]) {
    return await xHttp.post(FORM_DESIGN_URL.RESOURCE_UNBIND(formName), ids)
  }
}
