import xHttp from '@/apis/Xhttp'
import {
  queryAllRoleResult,
  roleData,
  queryAllRoleData,
  modifyRoleData,
  queryResourcesResult,
  unOrBindFormData,
  dataRulesResult,
  rulesData,
  queryAuthorizeMenusResult,
  authResourceResult,
  TreeData
} from './types'
import { ROLE_URL } from '@/apis/url'
export default {
  /**
   * 查询当前用户授权菜单树
   */
  async queryAuthorizeTreeMenus() {
    return await xHttp.get<TreeData[]>(ROLE_URL.MENU_TREE_LIST)
  },
  /**
   * 根据条件进行分页查询角色列表
   */
  async queryAllRole(params: queryAllRoleData = {}) {
    return await xHttp.get<queryAllRoleResult, queryAllRoleData>(ROLE_URL.LIST, params)
  },
  // 新增角色
  async addRole(param) {
    return await xHttp.post<void, roleData>(ROLE_URL.ADD, param)
  },
  // 更新角色
  async modifyRole(id, param) {
    return await xHttp.put<void, modifyRoleData>(ROLE_URL.MODIFY(id), param)
  },
  // 删除角色
  async deleteRole(id) {
    return await xHttp.delete<void, modifyRoleData>(ROLE_URL.DELETE(id))
  },
  /**
   * 获取表单授权的角色信息
   * @param {*} formId 表单ID
   * @returns
   */
  async getRoleFormList(roleId) {
    return await xHttp.get<queryResourcesResult[], modifyRoleData>(ROLE_URL.ROLE_FORM_LIST(roleId))
  },
  /**
   * 向角色授权表单
   * @param {*} roleId 角色ID
   * @param {*} formId 表单ID
   * @returns
   */
  async bindForm(roleId, formId) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.BIND_FORM(roleId), formId)
  },
  /**
   * 向角色取消表单授权
   * @param {*} roleId 角色ID
   * @param {*} formId 表单ID
   * @returns
   */
  async unbindForm(roleId, formId) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.UNBIND_FORM(roleId), formId)
  },
  // 获取被选中的规则的所有id
  async getDataRules(roleId, formId) {
    return await xHttp.get<dataRulesResult, rulesData>(ROLE_URL.DATA_RULE_LIST(roleId), {
      rule_table: formId
    })
  },
  // 授权规则
  async bindDataRule(roleId, ruleIds) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.BIND_DATA_RULE(roleId), ruleIds)
  },
  // 取消规则授权
  async unbindDataRule(roleId, ruleIds) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.UNBIND_DATA_RULE(roleId), ruleIds)
  },
  /**
   * 查询角色菜单列表(把子树平铺)
   * @param {string} roleId 角色id
   */
  async queryAuthorizeMenus(roleId) {
    return await xHttp.get<queryAuthorizeMenusResult[]>(ROLE_URL.MENU_LIST(roleId), {})
  },
  /**
   * 角色授权菜单
   * @param {string} roleId 角色id
   * @param {array} menuIds 菜单id数组
   */
  async authorizeMenu(roleId, menuIds) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.AUTHORIZE_MENU(roleId), menuIds)
  },
  /**
   * 角色取消授权菜单
   * @param {string} roleId 角色id
   * @param {array} menuIds 资源id数组
   */
  async revokeMenu(roleId, menuIds) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.REVOKE_MENU(roleId), menuIds)
  },
  /**
   * 角色授权资源(接口）
   * @param {string} roleId 角色id
   * @param {array} resourceIds 资源id数组
   */
  async authorizeResource(roleId, resourceIds) {
    return await xHttp.post<void, unOrBindFormData>(
      ROLE_URL.AUTHORIZE_RESOURCE(roleId),
      resourceIds
    )
  },
  /**
   * 角色取消授权资源（接口）
   * @param {string} roleId 角色id
   * @param {array} resourceIds 资源id数组
   */
  async revokeResource(roleId, resourceIds) {
    return await xHttp.post<void, unOrBindFormData>(ROLE_URL.REVOKE_RESOURCE(roleId), resourceIds)
  },
  // 授权资源查询(接口)
  async authResource(roleId, params) {
    return await xHttp.get<authResourceResult[], unOrBindFormData>(
      ROLE_URL.AUTH_RESOURCE(roleId),
      params
    )
  }
}
