export const LOGIN_URL = {
  LOGIN: 'oauth/token',
  REGISTER: 'user/register',
  RESET: 'user/reset',
  LOGOUT: 'oauth/logout'
}

export const SMS_URL = {
  IMAGE_CODE: 'sms/getImgCode',
  SMS_REGISTER: 'sms/register',
  SMS_RESET: 'sms/reset'
}

export const FILE_URL = {
  DELETE: (id) => `attachment/${id}`,
  STS_URL: `sts/getTempToken`
}

export const RESOURCE_URL = {
  RESOURCE_LIST: 'resource',
  RULE_LIST: (resourceId) => `resource/${resourceId}/rule`,
  ADD_RULE: (resourceId) => `resource/${resourceId}/rule`,
  MODIFY_RULE: (resourceId) => `resource/${resourceId}/rule`,
  DELETE_RULE: (ruleId) => `resource/rule/${ruleId}`
}

export const MENU_URL = {
  TREE_LIST: 'menu/tree',
  ADD_MENU: 'menu',
  UPDATE_MENU: (id) => `menu/${id}`,
  DELETE_MENU: (id) => `menu/${id}`
}

export const USER_URL = {
  LIST: 'user',
  ADD_USER: 'user',
  MODIFY_USER: (id) => `user/${id}`,
  SUSPEND_USER: (id) => `user/${id}/disable`,
  RESUME_USER: (id) => `user/${id}/enable`,
  DELETE_USER: (id) => `user/${id}`,
  // md5格式
  RESET_PASSWORD: 'user/admin/resetPasswordMd5',
  // 普通格式
  // RESET_PASSWORD: "user/admin/resetPassword",
  OPERATIONS_URL: 'login/search' // 用户运维列表
}

export const ORGANIZATION_URL = {
  LIST: 'organization/search',
  TREE_LIST: 'organization/tree',
  ADD: 'organization',
  MODIFY: (id) => `organization/${id}`,
  DELETE: (id) => `organization/${id}`,
  USER_LIST: (id) => `organization/${id}/user`,
  BIND_USER: (id) => `organization/${id}/user/bind`,
  UNBIND_USER: (id) => `organization/${id}/user/unbind`
}

export const ROLE_URL = {
  LIST: 'role',
  ADD: 'role',
  MODIFY: (id) => `role/${id}`,
  DELETE: (id) => `role/${id}`,
  USER_LIST: (id) => `role/${id}/user`,
  BIND_USER: (id) => `role/${id}/user/bind`,
  UNBIND_USER: (id) => `role/${id}/user/unbind`,
  RESOURCES_LIST: (id) => `role/${id}/resource`,
  AUTHORIZE_RESOURCE: (id) => `role/${id}/resource/bind`,
  REVOKE_RESOURCE: (id) => `role/${id}/resource/unbind`,
  MENU_TREE_LIST: 'menu/self/tree',
  MENU_TREE_ROLE_LIST: (roleId) => `/menu/${roleId}/tree`,
  MENU_LIST: (id) => `role/${id}/menu`,
  AUTHORIZE_MENU: (id) => `role/${id}/menu/bind`,
  REVOKE_MENU: (id) => `role/${id}/menu/unbind`,
  RESOURCE_RULE_LIST: (roleId, resourceId) => `role/${roleId}/resource/${resourceId}/rules`,
  AUTHORIZE_RESOURCE_RULE: (id) => `role/${id}/resource/rule/bind`,
  REVOKE_RESOURCE_RULE: (id) => `role/${id}/resource/rule/unbind`,
  AUTHORIZE_MENU_RULE: (id) => `role/${id}/menu/rule/bind`,
  REVOKE_MENU_RULE: (id) => `role/${id}/menu/rule/unbind`,
  MENU_RULE_LIST: (roleId, menuId) => `role/${roleId}/menu/${menuId}/rules`,
  BIND_FORM: (roleId) => `role/${roleId}/table/bind`,
  UNBIND_FORM: (roleId) => `role/${roleId}/table/unbind`,
  ROLE_FORM_LIST: (roleId) => `role/${roleId}/table`,
  FORM_ROLE_LIST: (formName) => `resource/table/${formName}/role`,
  DATA_RULE_LIST: (roleId) => `role/${roleId}/rule`,
  BIND_DATA_RULE: (roleId) => `role/${roleId}/rule/bind`,
  UNBIND_DATA_RULE: (roleId) => `role/${roleId}/rule/unbind`,
  AUTH: (roleId) => `role/${roleId}/table/bind`,
  AUTH_REVOKE: (roleId) => `role/${roleId}/table/unbind`,
  AUTH_SEARCH: (formName) => `resource/table/${formName}/role`,
  AUTH_RESOURCE: (roleId) => `/role/${roleId}/resource`
}

export const REGION_URL = {
  REGION: (parentCode) => `region/query/${parentCode}`,
  REGION_TREE: (parentCode) => `region/tree/${parentCode}`
}

/**
 * 表单部署
 */
export const FORM_DESIGN_URL = {
  QUERY: (formId) => `formDesign/${formId}`,
  DEPLOY: `formDesign`,
  UPDATE: (formId) => `formDesign/${formId}`,
  SEARCH: `formDesign`,
  DELETE: (formId) => `formDesign/${formId}?cascade=true`,
  FORM_IMPORT: `/table/import`,
  FORM_EXPORT: `/table/export`,
  RESOURCE_LIST: (formName) => `/resource/table/${formName}/role`,
  RESOURCE_BIND: (formName) => `/resource/table/${formName}/role/bind`,
  RESOURCE_UNBIND: (formName) => `/resource/table/${formName}/role/unbind`
}

/**
 * 表单数据操作
 */

export const FORM_DATA_URL = {
  ADD: (formName) => `form/${formName}`,
  SEARCH: (formName) => `form/${formName}/search`,
  JOIN_SEARCH: (formName) => `form/${formName}/joinSearch`,
  BATCH: (formName) => `form/${formName}/batch`,
  SEARCH_BY_ID: (formName, id, resolveDic, resolveSubItems) =>
    `form/${formName}/${id}?resolveDic=${resolveDic}&resolveSubItems=${resolveSubItems}`,
  DELETE_BY_ID: (formName, id) => `form/${formName}/${id}`,
  SEARCH_STATE: (formName, id, param) => `custom/form/${formName}/${id}/log?field=${param}`,
  UPDATE_STATE: (formName, id) => `custom/form/${formName}/${id}/state`,
  BATCH_STATE: (formName) => `custom/form/${formName}/state/batchUpdate`,
  BATCH_STATE_FILTER: (formName) => `custom/form/${formName}/state/batchUpdateByFilter`,
  UPDATE: (formName) => `form/${formName}`,
  IMPORT: (formName) => `form/${formName}/import`,
  COUNT: (formName) => `/form/${formName}/aggregation`
}

/**
 * 填报任务
 */
export const TASK_URL = {
  LIST: `resource/current/table`,
  GET: (dictName) => `form/task/${dictName}`
}

/**
 * 数据规则
 */
export const DATA_RULE_URL = {
  LIST: `dataRule`,
  GET: (ruleId) => `dataRule/${ruleId}`,
  ADD: `dataRule`,
  UPDATE: (ruleId) => `dataRule/${ruleId}`,
  DELETE: (ruleId) => `dataRule/${ruleId}`
}
