import xHttp from '@/apis/Xhttp'
import { USER_URL } from '@/apis/url'
import md5 from 'crypto-js/md5'
import { ModifyPasswordData } from './types'

export default {
  // 修改用户密码接口
  async userModifyPassword({ confirmPassword, newPassword, oldPassword }: ModifyPasswordData) {
    newPassword = md5(newPassword).toString()
    oldPassword = md5(oldPassword).toString()
    confirmPassword = md5(confirmPassword).toString()
    return await xHttp.post<any, ModifyPasswordData>('user/modifyPassword', {
      confirmPassword,
      newPassword,
      oldPassword
    })
  },
  // 用户编号查询
  async queryUserInfo(userId) {
    return await xHttp.get(`user/${userId}`)
  },
  async batchCreateUser({ code, roleId }) {
    return await xHttp.post('organUser/batchCreate', { code, roles: [roleId] })
  },
  // !上面是旧的接口，需要删除
  /**
   * 根据条件进行分页查询用户列表
   */
  async queryUserList({
    page,
    backRole = true,
    backOrganization = true,
    username,
    nickname,
    size
  }) {
    return xHttp.get(USER_URL.LIST, {
      page,
      backRole,
      backOrganization,
      username,
      nickname,
      size
    })
  },
  async getUserList(param) {
    return await xHttp.get(USER_URL.LIST, param)
  },
  // 保存用户接口
  async addUser(param) {
    param.password = md5(param.password).toString()
    return await xHttp.post(USER_URL.ADD_USER, param)
  },
  // 更新用户接口
  async updateUser(param) {
    // param["password"] = md5(param["password"]);
    return await xHttp.put(USER_URL.MODIFY_USER(param._id), param)
  },
  // 批量停用用户账号接口
  async suspendUser(userId) {
    return await xHttp.post(USER_URL.SUSPEND_USER(userId), {})
  },
  // 批量启用用户账号接口
  async resumeUser(userId) {
    return await xHttp.post(USER_URL.RESUME_USER(userId), {})
  },
  // 批量重置用户密码接口
  async resetUserPasswords(params) {
    // 可指定修改的password
    const { userIds } = params

    if (userIds.length === 0) {
      throw new Error('userIds不能为空')
    }

    return await xHttp.post(USER_URL.RESET_PASSWORD, params)
  },
  // 根据用户编号批量删除用户接口
  async deleteUser(userId) {
    return await xHttp.delete(USER_URL.DELETE_USER(userId))
  }
}
