import { filterRoleList } from './utils'
import { Props } from '../types'
import { keyBy } from 'lodash'
export default (props: Props) => {
  const dictsMap = keyBy(props.dicts, 'name')
  const DateRangeFieldType = 'DateRangeField'
  const operator_default = '='
  const DateRangeMap = ref({})
  const dateRangeFields = ref({})
  const searchMap = ref({})
  const isShow: Ref<boolean> = ref(false)
  //   获取格式化后的fields
  const searchFields: Ref<SEARCH.FIELD[]> = ref([])
  // 获取要显示的field
  const showSearchFields = computed(() => {
    const showSearchFields: any = []
    const fields = filterRoleList(props.fields)
    fields.forEach((item) => {
      const {
        renderer: {
          options: { hide, field }
        }
      } = item
      if (!hide) showSearchFields.push(field)
    })
    return showSearchFields
  })
  //   是否全部隐藏
  const allHide = computed(() => {
    return searchFields.value.every((item) => item['options']['hide'] == true)
  })
  watch(
    () => props.fields,
    (newValue) => {
      searchFields.value = getSearchFields(newValue)
      function getSearchFields(fields: SEARCH.FIELDS[]): SEARCH.FIELD[] {
        let searchFields: SEARCH.FIELD[] = []
        if (Array.isArray(fields) && fields.length != 0) {
          const newFields = filterRoleList(fields)
          searchFields = newFields.map((item) => {
            const { renderer, operator } = item
            const { options, type } = renderer
            // 兼容时间选择控件
            if (type == DateRangeFieldType) {
              const { startField, endField, field } = options
              DateRangeMap.value[startField!['field']] = {
                name: field,
                operator: startField!['operator'] || '>='
              }
              DateRangeMap.value[endField!['field']] = {
                name: field,
                operator: endField!['operator'] || '<='
              }
              dateRangeFields.value[field] = {
                startField: startField!['field'],
                endField: endField!['field']
              }
            } else {
              searchMap.value[options['field']] = operator || operator_default
              if (options.dictRef && !options.dict) {
                options.dict = dictsMap[options.dictRef] || {}
              }
            }
            // 去除不同权限不显示的组件
            const showIndex = showSearchFields.value.indexOf(options['field'])
            if (showIndex >= 0) {
              renderer.show = showIndex < props.showNum!
            } else {
              renderer.show = false
            }
            // options.formData = this.formData
            // 判断是否有初始值
            const defaultValue = props.defaultFields![options['field']]
            if (defaultValue) options['default'] = defaultValue
            return renderer
          })
        }
        isShow.value = false
        return searchFields
      }
    },
    { deep: true, immediate: true }
  )
  return {
    searchFields,
    showSearchFields,
    DateRangeMap,
    dateRangeFields,
    searchMap,
    isShow,
    allHide
  }
}
