import { Props } from '../config'
import { getOperators, getFormDef, setDefaultFields } from './methods'
import { keyBy } from 'lodash'
import { TABLE_OPERATORS, RECORD_OPERATORS } from '../config'
export default async (props: Props, route) => {
  // console.log('props :>> ', props)
  const formName: string = (route?.query?.form as string) || (props.formName as string)
  const formOptions = reactive({
    formDef: {},
    formRecordData: {},
    readonly: false
  })
  const getDef = (await getFormDef(formName)) as FORM.DEF
  //   增加自定义字典
  if (props.customDicts) {
    const mergeDicts = {
      ...keyBy(getDef['dicts'], 'name'),
      ...keyBy(props.customDicts, 'name')
    }
    getDef['dicts'] = Object.values(mergeDicts)
  }
  formOptions.formDef = getDef
  const { tableOptions } = props
  const { table, dicts } = getDef
  //   获取table上部按钮
  const tableOperators = computed(() => {
    let operators: any[] = TABLE_OPERATORS
    if (tableOptions?.tableOperators) {
      operators = getOperators(tableOptions.tableOperators, TABLE_OPERATORS)
    } else if (table?.tableOperators) {
      operators = getOperators(tableOperators, TABLE_OPERATORS)
    }
    return operators
  })
  //   获取table操作栏按钮
  const recordOperators = computed(() => {
    let operators: any[] = RECORD_OPERATORS
    if (tableOptions?.recordOperators) {
      operators = getOperators(tableOptions.recordOperators, RECORD_OPERATORS)
    } else if (table?.recordOperators) {
      operators = getOperators(recordOperators, RECORD_OPERATORS)
    }
    return operators
  })
  const optionsObj = {
    searchFields: [],
    tableFields: [],
    outFields: [],
    groups: {}
  }
  if (typeof props.formTableOptionsHandler === 'function') {
    const getTable = await props.formTableOptionsHandler(table)
    const { tableFields, outFields, searchItems, groups } = getTable || {}
    optionsObj.searchFields = searchItems || []
    optionsObj.tableFields = tableFields || []
    optionsObj.outFields = outFields || []
    optionsObj.groups = groups || {}
  } else {
    let { tableFields, outFields, searchItems, groups } = table || {}
    if (tableOptions?.searchItems) searchItems = tableOptions['searchItems']
    if (tableOptions?.tableFields) tableFields = tableOptions['tableFields']
    if (tableOptions?.outFields) outFields = tableOptions['outFields']
    if (tableOptions?.groups) groups = tableOptions['groups']
    optionsObj.searchFields = searchItems || []
    optionsObj.tableFields = tableFields || ([] as any)
    optionsObj.outFields = outFields || ([] as any)
    optionsObj.groups = groups || ({} as any)
  }
  const { defaultFields, regularFilter } = setDefaultFields(
    props.initFilter || [],
    optionsObj.searchFields
  )
  // 设置弹出框大小
  const modalWidth = tableOptions?.modalWidth || table?.modalWidth || '90%'
  return {
    formName,
    formOptions,
    dicts,
    recordOperators,
    tableOperators,
    ...optionsObj,
    defaultFields,
    regularFilter,
    modalWidth
  }
}
