import { intersection } from 'lodash'
// 定义常量
export const tableStatic = {
  dictSlotSuffix: '_dict',
  slotSuffix: '_slot',
  keySuffix: '_key',
  INDEX_NAME: '__index__',
  INDEX_LABEL: '序号',
  INDEX_WIDTH: 70,
  OPERATION_NAME: '__operation__',
  OPERATION_LABEL: '操作',
  changeSlotKeys: ['precision', 'unit', 'dateFormat'],
  columnArr: ['width', 'fixed', 'align', 'ellipsis', 'sorter'],
  changeSlotTypes: ['datetime', 'date', 'json'],
  pageSizeOptions: ['10', '20', '30', '40', '50']
}
interface FilterRoleList {
  <T>(list: T[]): T[]
}
// 判断是否根据不同角色来显示字段
export const filterRoleList: FilterRoleList = (list) => {
  if (!Array.isArray(list) || list.length === 0) return []
  const userInfo = JSON.parse(localStorage.getItem('userInfo')!)
  const roleCodes = userInfo['roles'].map(({ code }) => code)
  return list.filter((item) => {
    if (item['showRoles']) {
      let isShow = false
      for (const value of item['showRoles']) {
        if (roleCodes.includes(value)) {
          isShow = true
          break
        }
      }
      return isShow
    } else {
      return true
    }
  })
}
// 判断是否需要字典转化字段
export const isDictField = (field: TABLE.FIELDS): boolean => !!field.dict
// 判断是否为插槽字段
export const isSlotField = (field: TABLE.FIELDS): boolean => field.slot === true
// 判断是否需要格式化字段
export const isFormatField = (field: TABLE.FIELDS): boolean => {
  const { changeSlotKeys, changeSlotTypes } = tableStatic
  return (
    intersection(Object.keys(field), changeSlotKeys).length != 0 ||
    changeSlotTypes.includes(field.type!)
  )
}
