// export default columns=computed
import type { Props } from '../types'
import { filterRoleList, tableStatic } from './index'
import { cloneDeep, keyBy } from 'lodash'
interface Field {
  label: string
  name: string
  width?: number
  fixed?: string
  align?: string
}
export default (props: Props) => {
  const columns = ref<Field[]>([])
  // 获取table表头
  const genColumns = (props: Props): Field[] => {
    const { fields, groups, recordOperators } = props
    // console.log('groups :>> ', groups)
    // 设置表头分组
    // let groups = {
    //   耕地: [
    //     "耕地1",
    //     {
    //       耕地2: [
    //         "耕地2-1",
    //         {
    //           "耕地2-2": ["耕地2-2-1", "耕地2-2-3"],
    //         },
    //       ],
    //     },
    //     {
    //       耕地3: ["耕地3-1", { "耕地3-2": ["耕地3-2-1"] }],
    //     },
    //   ],
    // };
    if (!Array.isArray(fields) || fields.length == 0) return []
    let columns: Field[] = []
    // 生成字段列
    const groupsMap = mapTableGroups(groups)
    const newFields = filterRoleList(fields)
    newFields.forEach((field) => {
      const column = genColumn(field)
      let groupNames = groupsMap[field['name']]
      if (groupNames) {
        groupNames = groupNames.split(',')
        columnAddGroup(columns, groupNames)
        column['_pid'] = groupNames.at(-1)
      } else {
        column['_pid'] = -1
      }
      columns.push(column)
    })
    columns = arrayToTree(columns)
    // 生成序号列
    const indexField: Field = {
      label: tableStatic.INDEX_LABEL,
      name: tableStatic.INDEX_NAME,
      width: tableStatic.INDEX_WIDTH,
      align: 'center'
    }
    columns.unshift(genColumn(indexField))
    // 生成操作列
    const recordOperatorsList = filterRoleList(recordOperators || [])
    const recordLength = recordOperatorsList.length
    if (recordLength > 0) {
      const recordListLabelLength = recordOperatorsList.map((item) => item['label']).join('').length
      const field: Field = {
        label: tableStatic.OPERATION_LABEL,
        name: tableStatic.OPERATION_NAME,
        width: props.operatorWidth || recordListLabelLength * 30,
        fixed: 'right',
        align: 'center'
      }
      columns.push(genColumn(field))
    }
    return columns
  }
  // 获取table表头项单个配置
  const genColumn = (field) => {
    const { label, name } = field
    const column = {
      ...field,
      title: label,
      dataIndex: name,
      map_key: `${name}_head`
    }
    return column
  }
  const mapTableGroups = (groups, map = {}, parentGroupName?) => {
    if (Object.keys(groups).length === 0) return {}
    for (const key in groups) {
      const group = groups[key]
      if (Array.isArray(group)) {
        const groupNames = parentGroupName ? `${parentGroupName},${key}` : key
        group.forEach((item) => {
          if (typeof item === 'object') {
            map = mapTableGroups(item, map, groupNames)
          } else {
            map[item] = groupNames
          }
        })
      }
    }
    return map
  }
  const columnAddGroup = (columns, groupNames) => {
    const columnsMap = keyBy(columns, 'title')
    groupNames.forEach((name, index) => {
      if (!columnsMap[name]) {
        const _pid = index === 0 ? -1 : groupNames[index - 1]
        columns.push({
          title: name,
          map_key: name,
          _pid,
          align: 'center',
          children: []
        })
      }
    })
  }
  const arrayToTree = (items) => {
    items = cloneDeep(items)
    const res: any[] = [],
      map = {}
    for (const i of items) {
      map[i.map_key] = { ...i }
    }
    for (const i of items) {
      const newItem = map[i.map_key]
      if (i._pid === -1) {
        res.push(newItem)
      } else {
        if (map[i._pid]) map[i._pid].children.push(newItem)
      }
    }
    return res
  }
  columns.value = genColumns(props)
  return { columns }
}
