import { message } from 'ant-design-vue'
import { cloneDeep } from 'lodash'
import type { Props } from '../types'
import { parseDict } from '@/utils/dict'

export default (props: Props) => {
  onMounted(async () => {
    getDicts()
  })
  const dictsParse = ref({})
  // 获取字典的值
  const getDicts = async () => {
    try {
      if (!props.dicts || props.dicts.length === 0) return
      const dictsData = {}
      const dicts: FORM.DICT[] = props.dicts
      for (const key in dicts) {
        const { name } = dicts[key]
        dictsData[name] = await parseDict(dicts[key])
      }
      dictsParse.value = dictsData
    } catch (error) {
      message.error(`获取字典表时${error.msg}`)
    }
  }
  const getDictValue = computed(() => {
    return (field, value, type) => {
      const dictItem = getDictItem(field, value)
      if (!dictItem) return
      return dictItem[type]
    }
  })
  // 获取转化字典data
  const getDictItem = (field: TABLE.FIELDS, value) => {
    if (!field.dict) return
    let dictData = dictsParse.value[field.dict]
    if (!dictData) return
    if (Array.isArray(value)) {
      dictData = flatDictData(dictData)
      return dictData.filter((item) => value.includes(item.value))
    } else {
      return dictData.find((item) => item.value == value)
    }
  }
  // 扁平化字典值取label和value
  const flatDictData = (data) => {
    data = cloneDeep(data)
    data.forEach((item) => {
      const { children } = item
      if (Array.isArray(children)) {
        data.push(...flatDictData(children))
      }
      delete item.children
    })
    return data
  }
  return { getDictItem, dictsParse, getDictValue }
}
