import { isNaN } from 'lodash'
import { tableStatic } from './index'
import dayjs from 'dayjs'

export default (getDictItem) => {
  // 格式化字段函数
  const formatFieldValue = (text: any, field: TABLE.FIELDS) => {
    const { type, precision, unit, dict } = field
    let value: any
    if (tableStatic.changeSlotTypes.includes(type!)) {
      switch (type) {
        case 'datetime':
        case 'date':
          value = dateFormat(text, type, field['dateFormat'])
          break
        case 'json':
          if (Array.isArray(text)) {
            // 判断json是否为字典对应值
            if (dict) {
              const dataArrays = getDictItem(field, text)
              if (Array.isArray(dataArrays)) {
                value = dataArrays.map(({ label }) => label).join(',')
              } else {
                value = ''
              }
            } else {
              value = text.join(',')
            }
          }
          break
      }
    }
    if (precision && !isEmpty(text) && !isNaN(Number(text))) {
      value = parseFloat(parseFloat(value).toFixed(precision))
    }
    if (unit && !isEmpty(text)) {
      value += field['unit']
    }
    return value
  }
  const dateFormat = (date, type, fmt = '') => {
    if (!date) return ''
    if (fmt === '') fmt = type === 'date' ? 'YYYY-MM-DD' : 'YYYY-MM-DD HH:mm:ss'
    return dayjs(date).format(fmt)
  }
  const isEmpty = (value): boolean => [undefined, null, ''].includes(value)
  return { formatFieldValue }
}
