import ComparatorFactory from '@/components/form/GTForm/comparator/Factory'
import type { Props } from '../types'
import { filterRoleList } from './index'

export default (props: Props) => {
  const tableOperatorsList = computed((): TABLE.TABLE_OPERATORS[] => {
    return filterRoleList<TABLE.TABLE_OPERATORS>(props.tableOperators!)
  })
  const recordOperatorsList = computed((): TABLE.RECORD_OPERATORS[] => {
    return filterRoleList<TABLE.RECORD_OPERATORS>(props.recordOperators!)
  })
  const getVisible = (expression, record): boolean => {
    // 是否显示
    if (!expression) return true
    if (typeof expression === 'function') {
      return expression(record)
    } else if (Array.isArray(expression)) {
      const comparator = ComparatorFactory.createComparator(expression, record)
      return comparator!.compare()
    } else {
      return new Function('record', `return record.${expression}`)(record)
    }
  }
  //   是否禁用
  const getDisabled = (expression, record): boolean => {
    if (!expression) return false
    if (typeof expression === 'function') {
      return expression(record)
    } else if (Array.isArray(expression)) {
      const comparator = ComparatorFactory.createComparator(expression, record)
      return comparator!.compare()
    } else {
      return new Function('record', `return record.${expression}`)(record)
    }
  }

  return { tableOperatorsList, recordOperatorsList, getVisible, getDisabled }
}
