import type { Props, backParams } from './types'
import { genPlaceholderValue, updateVisibility, calcValue, fieldInDepends } from './utils'
export default (props: Props): backParams => {
  const inputValue = ref<any>(undefined)
  const label = computed(() => props.options.label)
  const required = computed(() => props.options.required === true)
  const field = computed(() => props.options.field).value
  const readonly = computed(() => !!props.options.readonly)
  const placeholder = computed(() => props.options.placeholder || `请输入${props.options.label}`)
  const hide = computed(() => !!props.options.hide)
  const formData = computed(() => props.formData).value
  const depends = computed(() => props.options.depends).value
  const calculator = computed(() => props.options.calculator).value

  // 初始化input参数和触发change
  const setValue = (value): void => {
    inputValue.value = value
    eventBus.emit('change', { field, value })
  }
  // 获取当前值
  const getValue = (): any => {
    return formData[field]
  }
  // 重置
  const reset = () => {
    setValue(null)
  }
  // 监听form表单值的变化
  const formChangeHandler = (payload: FORM.CHANGE_FIELDS): void => {
    // console.log('depends :>> ', depends)
    if (depends) dependsHandler(payload.field)
    if (calculator) calculatorHandler(payload)
    // if (payload.field == field) {
    //   console.log('form表单值的变化 :>> ', payload, formData)
    // }
  }
  const calculatorHandler = (payload: FORM.CHANGE_FIELDS) => {
    if (payload.field === field) return
    const { value, state } = calcValue(calculator, formData, payload) || {}
    if (state) {
      // console.log('object :>> ', value, state, payload.field)
      setValue(value)
    }
  }
  // 依赖
  const dependsHandler = (changeField = '') => {
    if (changeField !== '' && !fieldInDepends(changeField, depends)) return
    const visible = updateVisibility(depends, formData, {})
    eventBus.emit('visibleChange', { field, state: visible })
  }
  const eventBus = inject('eventBus') as any
  const formRecordData = (inject('formRecordData') as any) || {}
  eventBus.on('change', formChangeHandler)
  onMounted(() => {
    const { options } = props
    let value = null
    if (depends) dependsHandler()
    if (!field) return
    // updateVisibility
    if (![undefined, null, ''].includes(formRecordData[field])) {
      value = formRecordData[field]
    } else if (![undefined, null, ''].includes(options.default)) {
      value = genPlaceholderValue(options.default)
    }
    if (value !== null) {
      inputValue.value = value
      eventBus.emit('change', { field, value })
    }
  })
  onUnmounted(() => {
    if (!field) return
    eventBus.emit('change', { field, value: null })
  })
  return {
    inputValue,
    label,
    required,
    readonly,
    field,
    hide,
    placeholder,
    setValue,
    getValue,
    eventBus,
    reset,
    formRecordData
  }
}
