import ComparatorFactory from '../GTForm/comparator/Factory'
import CalculatorFactory from '../GTForm/calculator/Factory'
// 生成默认值
export function genPlaceholderValue(value: any): any {
  const VALUE_PLACEHOLDER = {
    DATE_NOW: 'now',
    USER_CONTACT: 'contact',
    USER_NICKNAME: 'nickname',
    USER_COMPANY: 'company',
    USER_PNAME: 'pname',
    USER_PCODE: 'pcode',
    USER_CNAME: 'cname',
    USER_CCODE: 'ccode',
    USER_FNAME: 'fname',
    USER_FCODE: 'fcode'
  }
  const userInfo = JSON.parse(localStorage.getItem('userInfo') || '')
  const VALUE_PLACEHOLDER_REGEXP = /\{.+?\}/g
  if (typeof value === 'undefined' || value === null) return
  const items = `${value}`.match(VALUE_PLACEHOLDER_REGEXP)
  if (items === null) return value
  const key = items[0].substr(1, items[0].length - 2).replace('user.', '')
  switch (key) {
    case VALUE_PLACEHOLDER.DATE_NOW:
      value = new Date().getTime()
      break
    case VALUE_PLACEHOLDER.USER_CONTACT:
      value = userInfo['phone']
      break
    case VALUE_PLACEHOLDER.USER_NICKNAME:
    case VALUE_PLACEHOLDER.USER_COMPANY:
    case VALUE_PLACEHOLDER.USER_PNAME:
    case VALUE_PLACEHOLDER.USER_PCODE:
    case VALUE_PLACEHOLDER.USER_CNAME:
    case VALUE_PLACEHOLDER.USER_CCODE:
    case VALUE_PLACEHOLDER.USER_FNAME:
    case VALUE_PLACEHOLDER.USER_FCODE:
      value = [null, ''].includes(userInfo[key]) ? undefined : userInfo[key]
      break
  }
  return value
}
// 自动显示或隐藏
export function updateVisibility(depends, formData, parentFormData) {
  const comparator = ComparatorFactory.createComparator(depends, formData, parentFormData)
  return comparator!.compare()
}
// 判断是否在depends里面
export function fieldInDepends(field, depends) {
  let res = false
  if (Array.isArray(depends)) {
    depends = depends.flat(Infinity)
    res = depends.includes(field)
  }
  return res
}
// 自动计算
export function calcValue(calculator, formData, payload) {
  const { field, data } = payload
  // 处理自动计算的逻辑
  const calc = CalculatorFactory.createCalculator(calculator, formData, data)
  if (!calc) return
  const fields = calc.getFields()
  if (!fields) return
  const value = calc.calc()
  // 判断field是否在计算器表达式内
  const state = fields.includes(field)
  return { value, state }
}
