import { keyBy, cloneDeep, isBoolean } from 'lodash'
import { FormOptions, typeOptions } from '../types'
export default (options: FormOptions) => {
  // 生成布局，在表单定义中layout的基础上，补齐相应的内容，如字典
  const visibleMap = ref({})
  let dictMap = {}
  const layout = ref<typeOptions[]>([])
  // computed(() => {
  //   return genLayout(options.formDef.layout)
  // })
  const itemLayout = ref({ layout: 'vertical' })
  const genLayout = (layout) => {
    if (!layout) return []
    if (!Array.isArray(layout)) {
      itemLayout.value = genItemLayout(layout.itemOptions)
      layout = layout.children || []
    }
    dictMap = keyBy(options.formDef.dicts, 'name')
    layout = cloneDeep(layout)
    layout.forEach((component: typeOptions) => {
      //   if (!component.options || component.options.visible !== false) {
      _handleComponent(component)
      //   } else {
      //     layout.splice(index, 1)
      //   }
    })
    return layout
  }
  const _handleComponent = (component) => {
    if (!component?.options) return
    const componentOptions = component.options
    const { dictRef, field } = componentOptions
    const { readonly, readonlyFields, formHelpData = {} } = options
    // 处理字典
    if (dictRef) componentOptions.dict = dictMap[dictRef]
    // 设置只读
    if (readonly) {
      componentOptions.readonly = true
    } else if (readonlyFields) {
      if (readonlyFields === '*') {
        componentOptions.readonly = true
      } else {
        const readonlyFieldArr = readonlyFields.split(',')
        if (readonlyFieldArr.includes(field)) {
          componentOptions.readonly = true
        }
      }
    }
    // 设置help数据
    if (formHelpData[field]) {
      componentOptions['help'] = formHelpData[field]
    }
    if (isBoolean(visibleMap.value[field])) {
      componentOptions['visible'] = visibleMap.value[field]
    }
    // 添加formData，有label属性被认为是字段组件
    // if (options.label || options.depends) {
    //   options.formData = this.formData
    // }
    if (Array.isArray(componentOptions.children)) {
      componentOptions.children.forEach((comp) => {
        // if (!comp.options || comp.options.visible !== false) {
        _handleComponent(comp)
        // } else {
        //   options.children.splice(index, 1)
        // }
      })
    }
  }
  const genItemLayout = (itemOptions = {}) => {
    return {
      layout:
        itemOptions['labelPosition'] === 'left' || itemOptions['labelSpan']
          ? 'horizontal'
          : 'vertical',
      labelCol: { span: itemOptions['labelSpan'] },
      wrapperCol: { span: itemOptions['wrapperSpan'] },
      labelAlign: itemOptions['labelAlign'],
      hideRequiredMark: itemOptions['hideRequiredMark']
    }
  }
  // 监听layout和visible变化来改变layout
  watch(
    [() => options.formDef.layout, visibleMap],
    ([newLayout]) => {
      // console.log('new :>> ', newLayout)
      layout.value = genLayout(newLayout)
    },
    { deep: true, immediate: true }
  )
  return { layout, itemLayout, visibleMap }
}
