import { FormOptions } from '../types'
import ValidatorFactory from '../validator/Factory'
import { message } from 'ant-design-vue'

export default (options: FormOptions, formData) => {
  const rules = computed(() => {
    return genRules(options.formDef)
  })
  const formRules = computed(() => {
    return genFormRules(options.formDef, formData)
  })
  // 生成校验规则
  const genRules = (formDef) => {
    let rules = {}
    const { fieldValidators, subformValidators } = formDef?.validators || {}
    // 字段校验器
    if (Array.isArray(fieldValidators)) {
      fieldValidators.forEach(({ field, label, validators }) => {
        rules[field] = _genRules(label, validators)
      })
    }
    // 子表单校验器
    if (Array.isArray(subformValidators)) {
      subformValidators.forEach(({ subform, label, validators }) => {
        rules[subform] = _genRules(label, validators, true)
      })
    }
    return rules
  }
  const _genRules = (fieldLabel, validators, isSubForm = false) => {
    let rules: any[] = []
    if (validators && Array.isArray(validators)) {
      validators.forEach((validator) => {
        // 判断是否为子表验证
        validator['isSubForm'] = isSubForm
        const vd = ValidatorFactory.createValidator(fieldLabel, validator, formData.value)
        // if (isSubForm) {
        //   console.log("vd :>> ", vd.getRule());
        // }
        if (vd) {
          rules.push(vd.getRule())
        }
      })
    }
    return rules
  }
  //  表单级校验器
  const genFormRules = (formDef, formData) => {
    const { formValidators } = formDef.validators || {}
    if (!Array.isArray(formValidators)) return []
    const vds: any[] = []
    formValidators.forEach((validator) => {
      const vd = ValidatorFactory.createValidator('表单数据', validator, formData.value)
      if (vd) {
        vds.push(vd.getRule())
      }
    })
    return vds
  }
  //   表单级校验
  const validateForm = () => {
    if (formRules.value.length === 0) return true
    for (let rule of formRules.value) {
      if (rule.validator && !rule.validator()) {
        message.error(rule.message)
        return false
      }
    }
    return true
  }
  return { rules, validateForm }
}
