import RequiredValidator from './Required'
import NumberRangeValidator from './NumberRange'
import TextRangeValidator from './TextRange'
import RegExpValidator from './RegExp'
import CompareValidator from './Compare'
import ItemCount from './ItemCount'

enum VALIDATOR_TYPES {
  REQUIRED = 'required',
  NUMBER_RANGE = 'number-range',
  TEXT_RANGE = 'text-range',
  REGEX = 'regex',
  COMPARE = 'compare',
  ITEM_COUNT = 'item-count'
}

const createValidator = (fieldLabel, validator, formData) => {
  if (!fieldLabel || !validator || !formData) return
  switch (validator.type) {
    case VALIDATOR_TYPES.REQUIRED:
      return new RequiredValidator(fieldLabel, validator, formData)
    case VALIDATOR_TYPES.NUMBER_RANGE:
      return new NumberRangeValidator(fieldLabel, validator, formData)
    case VALIDATOR_TYPES.TEXT_RANGE:
      return new TextRangeValidator(fieldLabel, validator, formData)
    case VALIDATOR_TYPES.REGEX:
      return new RegExpValidator(fieldLabel, validator, formData)
    case VALIDATOR_TYPES.COMPARE:
      return new CompareValidator(fieldLabel, validator, formData)
    case VALIDATOR_TYPES.ITEM_COUNT:
      return new ItemCount(fieldLabel, validator, formData)
  }
}

export default { createValidator }
