import dayjs from 'dayjs'
import { customAlphabet } from 'nanoid'
import Base64 from 'crypto-js/enc-base64'
import HmacSHA1 from 'crypto-js/hmac-sha1'
import Utf8 from 'crypto-js/enc-utf8'
import fileApi from '@/apis/file'
import { message } from 'ant-design-vue'
const VALID_MINUTES = 5
const CONTENT_LENGTH_MAX = 1024 * 1024 * 1024

export const nanoid = customAlphabet('abcdefghijklmnopqrstuvwxyz1234567890', 32)

function genSignature(accessKeySecret) {
  const date = new Date()
  date.setMinutes(date.getMinutes() + VALID_MINUTES)
  const policyText = JSON.stringify({
    expiration: date.toISOString(),
    conditions: [['content-length-range', 0, CONTENT_LENGTH_MAX]]
  })
  const policy = Base64.stringify(Utf8.parse(policyText))
  const signature = Base64.stringify(HmacSHA1(policy, accessKeySecret))
  return {
    policy,
    signature
  }
}
function genFileName(fileSuffix, path = '', dir = '') {
  if (!fileSuffix) return ''
  const uploadDate = dayjs().format('YYYYMMDD')
  const fileNameId = nanoid()
  const dirPath = dir ? `${dir}/` : ''
  return `${dirPath}${path}/${uploadDate}/${fileNameId}.${fileSuffix}`
}
function getFileSuffix(fileName) {
  const index = fileName.lastIndexOf('.')
  return index === -1 ? 'notype' : fileName.slice(index + 1)
}
export async function getUploadData(file, path) {
  const stsConfig = await fileApi.getTempToken()
  if (!stsConfig) {
    message.error('未获取oss地址配置，请刷新页面！')
    return
  }
  const fileSuffix = getFileSuffix(file.url || file.name)
  const { accessKeySecret, accessKeyId, securityToken, endPoint, dir } = stsConfig
  const fileName = genFileName(fileSuffix, path, dir)
  const { policy, signature } = genSignature(accessKeySecret)
  const data: any = new FormData()
  data.append('key', fileName)
  data.append('name', file.name)
  data.append('policy', policy)
  data.append('signature', signature)
  data.append('OSSAccessKeyId', accessKeyId)
  data.append('success_action_status', 200)
  data.append('x-oss-security-token', securityToken)
  data.append('file', file)
  return { endPoint, data, fileName }
}
// 检测图片类型
export function testFormat(name, accept) {
  if (!accept) return true
  accept = accept.split(',')
  name = name.toLocaleLowerCase()
  return accept.some((suffix) => name.endsWith(suffix))
}
// size单位byte
export function exceedSizeLimit(size, sizeLimit) {
  if (!sizeLimit) return false
  const fileSize = size / 1024
  if (fileSize > sizeLimit) return true
}
