import formDataApi from '@/apis/formData'
import { cloneDeep } from 'lodash'

enum DICT_TYPES {
  ENUM = 'enum',
  INLINE = 'inline',
  TABLE = 'table'
}

/**
 * 解析enum类型字典
 * @param {*} dictDef
 * @returns
 */
const parseEnumDict = (dictDef) => {
  if (!dictDef.items || !Array.isArray(dictDef.items)) return
  return dictDef.items.map((item) => {
    return {
      label: item,
      value: item,
      data: {
        label: item,
        value: item
      }
    }
  })
}
/**
 * 解析inline类型字典
 * @param {*} dictDef
 * @returns
 */
const parseInlineDict = (dictDef) => {
  const { items } = dictDef
  if (!items || !Array.isArray(items)) return
  return items.map((item) => {
    return {
      ...item,
      data: cloneDeep(item)
    }
  })
}

/**
 * 解析table类型字典
 * @param {*} dictDef
 */
const parseTableDict = async (dictDef, theFilter) => {
  const { name, labelField, valueField, fields, filter, orderField } = dictDef
  if (!name || !labelField || !valueField) return
  if (fields && !Array.isArray(fields)) return
  // 获取outFields参数
  let outFields = !fields ? [labelField, valueField] : fields
  outFields = Array.from(new Set(outFields))
  // 组合过滤条件
  let filters: any[] | undefined = ['and']
  if (filter) filters!.push(filter)
  if (theFilter) filters.push(theFilter)
  if (filters.length === 1) filters = undefined
  if (filters && filters.length === 2) filters = filters[1]
  // 获取字典数据
  const result = await formDataApi.searchFormData(name, {
    outFields,
    distinct: true,
    filter: filters
  })
  const { list } = result
  if (!list || !Array.isArray(list)) return
  if (orderField) {
    list.sort((a, b) => a[orderField] - b[orderField])
  }
  // 组装字典
  return list.map((item) => {
    return {
      label: item[labelField],
      value: item[valueField],
      data: item
    }
  })
}

export const parseDict = async (dictDef, filter?) => {
  if (!dictDef || !dictDef.type) return
  switch (dictDef.type) {
    case DICT_TYPES.ENUM:
      return parseEnumDict(dictDef)
    case DICT_TYPES.INLINE:
      return parseInlineDict(dictDef)
    case DICT_TYPES.TABLE:
      return await parseTableDict(dictDef, filter)
  }
}
