import { customAlphabet } from 'nanoid'
import { message } from 'ant-design-vue'
import { cloneDeep } from 'lodash'
let isTableField = false
let fromType = ''
let json_fields: any = []
let no_includes_field: any = []
// 设置唯一id
const nanoid = () => {
  return (
    customAlphabet('abcdefghijklmnopqrstuvwxyz', 1)() +
    customAlphabet('abcdefghijklmnopqrstuvwxyz1234567890', 9)()
  )
}
// 常用类型
// const COMMON_TYPE_LIST = ['CatalogueField', 'JsonField', 'PictureField', 'AdminField', 'CascaderField', 'CheckboxField', 'DateField', 'FileField', 'IntegerField', 'NumberField', 'NumberWithUnitField', 'RadioField', 'DateRangeField', 'SelectField', 'TextField', 'LonLatField', 'NumberWithUnitField']
// 特殊类型
export const SPECIAL_TYPE_LIST = {
  LonLatField: [
    'lonField',
    'latField',
    'pcodeField',
    'ccodeField',
    'fcodeField',
    'pnameField',
    'cnameField',
    'fnameField',
    'addressField'
  ],
  NumberWithUnitField: ['valueField', 'unitField'],
  DateRangeField: ['startField', 'endField'],
  AdminField: ['field', 'subField']
}
export const SPECIAL_TYPE_LISY = SPECIAL_TYPE_LIST
// form表单特殊处理
// const FORM_TYPE = ["SubForm", "TiledSubForm"];
function formatJson(layout, json, isApp) {
  if (Array.isArray(layout)) {
    layout.forEach((layoutItem) => {
      formatJson(layoutItem, json, isApp)
    })
  } else {
    const childrenList = layout?.options?.children
    if (Array.isArray(childrenList)) {
      childrenList.forEach((item) => {
        // 兼容app布局
        if (isApp && item.children) {
          item.children.forEach((i) => {
            setLayout(i, json, isApp)
          })
        } else {
          setLayout(item, json, isApp)
        }
      })
    } else {
      setLayout(layout, json, isApp)
    }
  }
}
function setLayout(item, json, isApp) {
  // if (COMMON_TYPE_LIST.includes(item.type)) {
  if (item?.type?.endsWith('Field')) {
    const fields = getFieldItems(item, json)
    if (isApp) {
      fields.forEach(({ field, label }) => {
        if (!json_fields.includes(field)) {
          no_includes_field.push(label)
        }
      })
    } else {
      // 生成fields
      setFields(fields, json)
      // 生成字典映射
      setDictRef(fields, json)
      // 生成table列表字段
      if (isTableField) {
        setTableFields(fields, json)
      }
    }
    // 生成验证条件
    setValidators(fields, json)
    // } else if (FORM_TYPE.includes(item.type)) {
  } else if (item?.type?.endsWith('SubForm')) {
    setForm(item, json, isApp)
  } else if (item?.options?.children) {
    formatJson(item, json, isApp)
  }
}
function setForm(item, json, isApp) {
  const { options } = item
  if (!options.field) options.field = nanoid()
  const fields = [
    {
      name: options.field,
      formUid: options.formUid,
      depends: options.depends,
      required: options.required,
      label: options.label,
      sorted_field: options.sorted_field
    }
  ]
  setValidators(fields, json, true)
  if (!isApp) {
    setSubTables(fields, json)
  }
}
function getFieldItems(items, json, isSpecial = false) {
  const arr: any[] = []
  const { type } = items
  const options = isSpecial ? items : items.options
  const obj = cloneDeep(options)
  if (SPECIAL_TYPE_LIST[type] && !isSpecial) {
    SPECIAL_TYPE_LIST[type].forEach((specialItems) => {
      if (typeof options[specialItems] === 'object') {
        if (!options[specialItems]?.field) {
          options[specialItems]['field'] = nanoid()
        }
        const item = cloneDeep(options[specialItems])
        item.depends = options.depends
        arr.push(...getFieldItems(item, json, true))
      }
    })
  } else {
    obj.name = options.field = options.field || nanoid()
    arr.push(obj)
  }
  return arr
}
function setFields(fieldsItems, json) {
  fieldsItems.forEach((fieldItem) => {
    const { label, type, name, unique, spareLabel } = fieldItem
    // let { required, label, type, name, depends } = fieldItem
    const oldFieldIndex = json.fields.findIndex((field) => field.name == name)
    const newField = {
      //如果有依赖则为空
      // required: !depends && required,
      required: false,
      unique,
      label,
      // 设置的导入导出Excel label
      spareLabel,
      type,
      name
    }
    if (oldFieldIndex == -1) {
      json.fields.push(newField)
    } else {
      json.fields.splice(oldFieldIndex, 1, newField)
    }
  })
}
function setDictRef(fieldItems, json) {
  fieldItems.forEach((fieldItem) => {
    if (fieldItem.dictRef) {
      json.dictRefs[fieldItem.name] = fieldItem.dictRef
    }
  })
}
function setValidators(fieldItems, json, isForm = false) {
  fieldItems.forEach((item) => {
    serValidator(item, json, isForm)
  })
  function serValidator(fieldItem, json, isForm) {
    const { name, depends, required, label } = fieldItem
    const nameKey = isForm ? 'subform' : 'field'
    const validatorsKey = isForm ? 'subformValidators' : 'fieldValidators'
    const validatorData = json.validators[validatorsKey] || []
    // 判断是否删除required
    if (!required) {
      json.validators[validatorsKey] = validatorData.filter((validator) => {
        if (!Array.isArray(validator['validators'])) {
          return false
        } else if (validator[nameKey] === name) {
          validator['validators'] = validator['validators'].filter(
            ({ type }) => type !== 'required'
          )
          return validator['validators'].length != 0
        } else {
          return true
        }
      })
    } else {
      const fieldValidator = validatorData.find((validator) => validator[nameKey] === name)
      if (fieldValidator) {
        if (depends) fieldValidator['depends'] = depends
        if (label) fieldValidator['label'] = label
        if (Array.isArray(fieldValidator.validators)) {
          const isRequired = fieldValidator.validators.some((item) => item['type'] === 'required')
          if (!isRequired) {
            fieldValidator.validators.push({ type: 'required' })
          }
        } else {
          fieldValidator.validators = [{ type: 'required' }]
        }
      } else {
        const validator = { label }
        validator[nameKey] = name
        if (depends || required) {
          if (depends) validator['depends'] = depends
          if (required) validator['validators'] = [{ type: 'required' }]
          validatorData.push(validator)
        }
      }
    }
  }
}
function setSubTables(fieldItems, json) {
  fieldItems.forEach(({ formUid, sorted_field }) => {
    const subTableItem = {
      name: formUid,
      fk: '__main_form_record_uid_field__'
    }
    // 判断子表是否有排序字段
    if (sorted_field) {
      subTableItem['sorted_field'] = sorted_field
    }
    json.subTables.push(subTableItem)
  })
}
function baseJson(json, isApp) {
  // if (Array.isArray(json.fields)) {
  //     // 保留主表记录UID
  //     json.fields = json.fields.filter(i => i.name == '__main_form_record_uid_field__')
  // } else {
  //     json.fields = []
  // }
  //     json.fields = []
  if (isApp) {
    if (!json.validators) json.validators = {}
    if (!json.validators.fieldValidators) json['validators']['fieldValidators'] = []
    if (!json.validators.subformValidators) json['validators']['subformValidators'] = []
    delete json['validators']['subFormValidators']
    return
  }
  if (!Array.isArray(json.fields)) json.fields = []
  json.subTables = []
  json.dictRefs = {}
  if (!json.validators) json.validators = {}
  if (!json.validators.fieldValidators) json['validators']['fieldValidators'] = []
  if (!json.validators.subformValidators) json['validators']['subformValidators'] = []
  if (!json.table) json.table = {}
  if (!Array.isArray(json.table.tableFields)) {
    json.table.tableFields = []
  }
  delete json['validators']['subFormValidators']
  isTableField = json.table.tableFields.length == 0
}

function setTableFields(fieldsItems, json) {
  fieldsItems.forEach((fieldItem) => {
    const { label, name, type } = fieldItem
    json.table.tableFields.push({
      label,
      name,
      type,
      width: 100
    })
  })
}
export function parseJson(json, isApp?) {
  if (!isApp) setFormType(json)
  if (!json.layout) return json
  // 初始化json
  baseJson(json, isApp)
  // 设置json
  let layout = json.layout
  if (json.layout.children) {
    layout = json.layout.children
  }
  formatJson(layout, json, isApp)
  // if (json["validators"]["subformValidators"].length == 0) {
  //   delete json["validators"]["subformValidators"];
  // }
  // 用来设置profile_mobile
  if (!isApp) {
    if (fromType == 'web') {
      json['profile_web'] = {
        layout: json['layout'],
        validators: json['validators']
      }
      //   delete json["layout"];
      //   delete json["validators"];
    }
    if (json['profile_mobile']) {
      json_fields = json['fields'].map((item) => item['name'])
      parseJson(json['profile_mobile'], 'app')
      if (no_includes_field.length > 0) {
        message.info(
          `app配置字段中 ${no_includes_field.join(',')} 无法在数据库字段中找到，请修改配置！`
        )
      }
      json_fields = []
      no_includes_field = []
      fromType = ''
    }
  }
  return json
  // 转化contains_any为contains-any
  // let jsonString = JSON.stringify(json);
  // jsonString = jsonString.replace(/contains_any/g, "contains-any");
  // return JSON.parse(jsonString);
}
// 兼容处理web和app
function setFormType(json) {
  if ((json['profile_web'] && json['profile_mobile']) || json['profile_web']) {
    json['layout'] = json['profile_web']['layout']
    json['validators'] = json['profile_web']['validators']
    fromType = 'web'
  } else {
    fromType = ''
  }
}
// 判断是否为json
export function isJSON(str) {
  if (typeof str == 'string') {
    try {
      var obj = JSON.parse(str)
      if (typeof obj == 'object' && obj) {
        return true
      } else {
        return false
      }
    } catch (e) {
      return false
    }
  }
}
