const dicts = [
  {
    name: 'hideshow',
    type: 'inline',
    items: [
      {
        label: '显示',
        value: 1
      },
      {
        label: '隐藏',
        value: 0
      }
    ]
  },
  {
    name: 'yn',
    type: 'inline',
    items: [
      {
        label: '是',
        value: 1
      },
      {
        label: '否',
        value: 0
      }
    ]
  },
  {
    name: 'componenturi',
    type: 'inline',
    items: setCascaderData()
  }
]

const dictRefs = {
  hide: 'hideshow',
  component: 'componenturi',
  secondmenu: 'yn'
}
const layout = {
  children: [
    {
      type: 'TextField',
      options: {
        type: 'text',
        field: 'name',
        label: '菜单名称',
        required: true
      }
    },
    {
      type: 'TextField',
      options: {
        type: 'text',
        field: 'uri',
        label: '访问路径',
        required: true
      }
    },
    {
      type: 'RadioField',
      options: {
        type: 'text',
        field: 'secondmenu',
        label: '是否为二级菜单',
        default: 0,
        dictRef: 'yn',
        required: true
      }
    },
    {
      type: 'CascaderField',
      options: {
        type: 'text',
        field: 'component',
        label: '显示组件',
        required: true,
        dictRef: 'componenturi',
        depends: ['==', 'secondmenu', 0]
      }
    },

    {
      type: 'iconField',
      options: {
        type: 'text',
        field: 'icon',
        label: '显示图标'
      }
    },
    {
      type: 'NumberField',
      options: {
        type: 'text',
        field: 'sort_no',
        label: '排序',
        required: true
      }
    },
    {
      type: 'RadioField',
      options: {
        type: 'number',
        field: 'hide',
        label: '是否显示',
        dictRef: 'hideshow',
        required: true,
        default: 1
      }
    }
  ]
}
const validators = {
  fieldValidators: [
    {
      field: 'name',
      label: '菜单名称',
      validators: [
        {
          type: 'regex',
          options: {
            pattern: /^\S+$/,
            message: '菜单名称不能包含空格'
          }
        }
      ]
    },
    {
      field: 'uri',
      label: '访问路径',
      validators: [
        {
          type: 'regex',
          options: {
            pattern: /^\S+$/,
            message: '访问路径不能包含空格'
          }
        }
      ]
    }
  ]
}
const formDef = {
  layout,
  dicts,
  dictRefs,
  validators
}
interface formRecordData {
  formDef: object
  formRecordData: object | undefined
}
export const options: formRecordData = {
  formDef,
  formRecordData: {}
}
function getComponent(rootPath) {
  const files = import.meta.globEager('/src/**/*.vue')
  const arr = Object.keys(files)
    .map((item) => {
      const newArr = item.replace('./', '').split('/')
      newArr.splice(0, 2)
      return newArr
    })
    .filter((item) => {
      return rootPath.includes(item[0]) && item.length > 1 && !item.includes('components')
    })
  return arr
}
function setCascaderData() {
  const allPathArray = getComponent(['app', 'views', 'pages'])
  const pathArray: any = []

  allPathArray.forEach((pathArr) => {
    let current = pathArray
    pathArr.forEach((path, index) => {
      const isExist = current.find((item) => item.value === path)
      if (isExist) {
        current = isExist.children || (isExist.children = [])
      } else {
        const obj: any = { value: path, label: path }
        current.push(obj)
        current = obj.children || (obj.children = [])
        if (index === pathArr.length - 1) {
          delete obj.children
        }
      }
    })
  })
  return pathArray
}
